# Create a Datacube for scaling geospatial analyses

See the testing files and DataCube class for more information on the API.  

Modified from a [tutorial](https://earthmover.io/blog/serverless-datacube-pipeline) by Ryan Abernathy and the Earthmover team.